from sqlalchemy import Column, Integer, String, TIMESTAMP, Text, ForeignKey, Enum
from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base

from .author import Author
from .book_category import BookCategory

Base = declarative_base()


class Book(Base):
    __tablename__ = 'book'

    id = Column(Integer, primary_key=True, autoincrement=True)
    author_id = Column(Integer, ForeignKey(
        'author.id'), nullable=False, index=True)
    title = Column(String(100), nullable=False)
    description = Column(Text, nullable=False)
    year_published = Column(String(4), nullable=False)
    isbn = Column(String(13), nullable=False, unique=True)
    status = Column(Enum('available', 'borrowed', 'reserved'),
                    nullable=False, default='available')
    created_at = Column(TIMESTAMP, nullable=True, default="CURRENT_TIMESTAMP")

    author = relationship('Author', back_populates='books')
    # loans = relationship('Loan', back_populates='book')
    categories = relationship(
        'BookCategory', secondary='book_category_link', back_populates='books')
